# Contributor Code of Conduct

Please be nice, respectful of differing viewpoints and experiences. Note that every piece of code has a history that is not free of time/money/personal constraints.

You may wonder about the coding style and libraries used. The project does not use every popular Javascript framework. This has the disadvantage that some things are slower to implement at first, but has the advantage that we potentially can get contributions from programmers who are not yet on the most recent frameworks and also that when something breaks, we do not have to dig through the implicit behavior that is part of the framework. We hope that contributors are not put off by this. We do appreciate any ideas on how to improve the UI system, possibly by adding a UI framework in a lightweight way or just in any way, as our experience with Javascript frameworks is extremely limited.

This is a relatively small software project and all contributors have all been extremely nice, which is why this Code of Conduct is very short. 
